@@ -10,9 +10,11 @@ use List::Util qw(max);
 use Crypt::RIPEMD160      ();
 use Digest::BLAKE         ();
 use Digest::BMW           ();
-use Digest::CubeHash      ();
+use Digest::CubeHash::XS  ();
 use Digest::ECHO          ();
+use Digest::EdonR         ();
 use Digest::Fugue         ();
+use Digest::GOST          ();
 use Digest::Groestl       ();
 use Digest::Hamsi         ();
 use Digest::JH            ();
@@ -50,18 +52,23 @@ my %digests = (
     bmw_256      => sub { Digest::BMW::bmw_256($data) },
     bmw_384      => sub { Digest::BMW::bmw_384($data) },
     bmw_512      => sub { Digest::BMW::bmw_512($data) },
-    cubehash_224 => sub { Digest::CubeHash::cubehash_224($data) },
-    cubehash_256 => sub { Digest::CubeHash::cubehash_256($data) },
-    cubehash_384 => sub { Digest::CubeHash::cubehash_384($data) },
-    cubehash_512 => sub { Digest::CubeHash::cubehash_512($data) },
+    cubehash_224 => sub { Digest::CubeHash::XS::cubehash_224($data) },
+    cubehash_256 => sub { Digest::CubeHash::XS::cubehash_256($data) },
+    cubehash_384 => sub { Digest::CubeHash::XS::cubehash_384($data) },
+    cubehash_512 => sub { Digest::CubeHash::XS::cubehash_512($data) },
     echo_224     => sub { Digest::ECHO::echo_224($data) },
     echo_256     => sub { Digest::ECHO::echo_256($data) },
     echo_384     => sub { Digest::ECHO::echo_384($data) },
     echo_512     => sub { Digest::ECHO::echo_512($data) },
+    edonr_224    => sub { Digest::EdonR::edonr_224($data) },
+    edonr_256    => sub { Digest::EdonR::edonr_256($data) },
+    edonr_384    => sub { Digest::EdonR::edonr_384($data) },
+    edonr_512    => sub { Digest::EdonR::edonr_512($data) },
     fugue_224    => sub { Digest::Fugue::fugue_224($data) },
     fugue_256    => sub { Digest::Fugue::fugue_256($data) },
     fugue_384    => sub { Digest::Fugue::fugue_384($data) },
     fugue_512    => sub { Digest::Fugue::fugue_512($data) },
+    gost         => sub { Digest::GOST::gost($data) },
     groestl_224  => sub { Digest::Groestl::groestl_224($data) },
     groestl_256  => sub { Digest::Groestl::groestl_256($data) },
     groestl_384  => sub { Digest::Groestl::groestl_384($data) },
